# !/usr/bin/env/Python3
import requests as req from bs4 
import BeautifulSoup as bs 

def save(fileName, document):
	with open(fileName+".txt","w") as f:
		f.write(""" 
		Your Current Search Results
                =================================================
                ||   Author: ||   TomsDroid || 
                ||   Credit: ||   Skull Cyber 
                ||   Security ~ ||   Indonesia ||
                =================================================\n\n""") 
                f.write(document)

def whois_domain(domain):
	url = req.get(f"https://www.shopify.com/tools/whois/search?query={domain}") 
  	soup = bs(url.text, "html.parser") 
	sortir = soup.find("section", {"class":"record-container"}) 
	sort = sortir.find("pre").get_text()
	return sort

def whois_ip(ipAddress):
	url = req.get(f"https://dnschecker.org/ip-whois-lookup.php?query={ipAddress}") 
	soup = bs(url.text, "html.parser")
	sortir = soup.find("li", {"class":"list-group-item"})
  	return sortir



from setuptools import setup,find_packages

def readme():
    with open(r'README.md') as f:
        README = f.read()
    return README

classifiers = [
    'Development Status :: 1 - Planning',
    'Intended Audience :: Education',
    'Operating System :: Unix',
    'Operating System :: MacOS :: MacOS X',
    'Operating System :: Microsoft :: Windows',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3'
]

setup(
    name='ScsLabs',
    version='0.0.4',
    description='ScsLabs adalah modul edukasi untuk Pemula / Expert.',
    long_description=readme(),
    long_description_content_type="text/markdown",
    url='https://github.com/SkullCyberSecurity/ScsLabs',
    author='TomsDroid',
    author_email='tomsdroid@kingeagle.tech',
    license='MIT',
    classifiers=classifiers,
    keywords=['scs', 'skullcybersecurity', 'whois-domain', 'whois'],
    packages=find_packages(),
    install_requires=['requests','beautifulsoup4']
)
